@@ -1,5 +1,5 @@
+#!/usr/bin/env python3
 import gi
-
 gi.require_version("Gtk", "3.0")
 gi.require_version('Budgie', '1.0')
 from gi.repository import Gdk, Gtk, GObject, GdkPixbuf, Budgie, Gio, GLib
@@ -15,7 +15,7 @@ import cwtools as cw
 """
 ClockWorks
 Author: Jacob Vlijm
-Copyright © 2017-2022 Ubuntu Budgie Developers
+Copyright © 2017 Ubuntu Budgie Developers
 Website=https://ubuntubudgie.org
 This program is free software: you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free Software
@@ -44,7 +44,6 @@ for dr in [hrs_path, mins_path]:
 
 hours = []
 minutes = []
-tz_data = cw.tz_data
 settings = cw.settings
 
 # create images
@@ -187,6 +186,7 @@ class BudgieClockWorksApplet(Budgie.Applet):
         icon = Gtk.Image.new_from_icon_name(
             "budgie-clockworks-symbolic", Gtk.IconSize.MENU
         )
+        self.tz_data = self.get_timerange()
         self.provider = Gtk.CssProvider.new()
         self.provider.load_from_data(clw_css_data.encode())
         # setup watching applet presence
@@ -243,6 +243,14 @@ class BudgieClockWorksApplet(Budgie.Applet):
         self.update.setDaemon(True)
         self.update.start()
 
+    def get_timerange(self):
+        timelabels = []
+        offset = -86400
+        while offset < 86401:
+            timelabels.append(self.convert_offset_tolabel(offset))
+            offset = offset + 900
+        return timelabels
+
     def watchout(self):
         path = "com.solus-project.budgie-panel"
         panelpath_prestring = "/com/solus-project/budgie-panel/panels/"
@@ -314,7 +322,9 @@ class BudgieClockWorksApplet(Budgie.Applet):
     def convert_offset_tolabel(self, offset):
         if offset != 0:
             prestring = "-" if offset < 0 else "+"
-            set_time_hrs = self.double_digits(str(int(abs(offset) / 3600)))
+            # calc with abs!
+            offset = abs(offset)
+            set_time_hrs = self.double_digits(str(int(offset / 3600)))
             set_time_mins = self.double_digits(str(int((offset % 3600) / 60)))
             return prestring + set_time_hrs + ":" + set_time_mins
         else:
@@ -324,7 +334,8 @@ class BudgieClockWorksApplet(Budgie.Applet):
         newval = label.split(":")
         hrs_offset = int(newval[0]) * 3600
         mins_offset = int(newval[1]) * 60
-        mins_offset = mins_offset if hrs_offset > 0 else -mins_offset
+        if label.startswith("-"):
+            mins_offset = -mins_offset
         return (hrs_offset + mins_offset)
 
     def save_tofile(self):
@@ -490,14 +501,14 @@ class BudgieClockWorksApplet(Budgie.Applet):
         # sets the time shift on combo change
         curr_offset = self.clocklist[clock]["offset"]
         nxt = -1 if down else +1
-        newindex = tz_data.index(
+        newindex = self.tz_data.index(
             self.convert_offset_tolabel(curr_offset)
         ) + nxt
         newindex = 0 if newindex < 0 else newindex
         try:
-            newlabel = tz_data[newindex]
+            newlabel = self.tz_data[newindex]
         except IndexError:
-            newlabel = tz_data[-1]
+            newlabel = self.tz_data[-1]
         label.set_text(newlabel)
         self.clocklist[clock]["offset"] = self.convert_label_tooffset(newlabel)
         curr_time = time.time()
